intelmq.bots.parsers.html_table package — intelmq 3.0.0.alpha.1 documentation

# intelmq.bots.parsers.html_table package

## Submodules

## intelmq.bots.parsers.html_table.parser module

HTML Table parser

Parameters: columns: string ignore_values: string skip_table_head: boolean attribute_name: string attribute_value: string table_index: int split_column: string split_separator: string split_index: int default_url_protocol: string time_format: string type: string

`intelmq.bots.parsers.html_table.parser.` `BOT`

  alias of `intelmq.bots.parsers.html_table.parser.HTMLTableParserBot`

class `intelmq.bots.parsers.html_table.parser.` `HTMLTableParserBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.Bot`

  Parse HTML table data

  `attribute_name` = ''
  `attribute_value` = ''
  `columns` = ['', 'source.fqdn']
  `default_url_protocol` = 'http://'
  `ignore_values` = None
  `init`()
  `process`()
  `skip_table_head` = True
  `split_column` = ''
  `split_index` = 0
  `split_separator` = None
  `table_index` = 0
  `time_format` = None
  `type` = 'c2-server'

## Module contents